==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/forum/lang/forum_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/forum?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_message_forum' => 'لا يوجد مشاركات منتدى',

	// B
	'bouton_radio_articles_futurs' => 'على المقالات المستقبلية فقط (لا تأثير على قاعدة البيانات).',
	'bouton_radio_articles_tous' => 'على كل المقالات دون استثناء.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'على كل المقالات باستثناء المقالات ذات المنتديات المتوقفة.',
	'bouton_radio_enregistrement_obligatoire' => 'تسجيل إجباري (
يجب على المستخدمين التسجيل بإدخال عنوانهم البريدي قبل
التمكن من إرسال المشاركات).',
	'bouton_radio_moderation_priori' => 'مراقبة استباقية (
لا تظهر المشاركات إلا بعد تصديقها من قبل
المدراء).',
	'bouton_radio_modere_abonnement' => 'اشتراك إجباري',
	'bouton_radio_modere_posteriori' => 'مراقبة بعدية',
	'bouton_radio_modere_priori' => 'مراقبة استباقية',
	'bouton_radio_publication_immediate' => 'نشر فوري للمشاركات
(ستظهر المشاركات حال إرسالها، ويمكن للمدراء
حذفها وقتذاك).',

	// D
	'documents_interdits_forum' => 'المستندات ممنوعة في المنتدى',

	// E
	'erreur_enregistrement_message' => 'لم يتم تسجيل مشاركتك بسبب مشكلة تقنية',
	'extensions_autorisees' => 'اللواحق المسموح بها:',
	'extensions_autorisees_lien' => 'عرض كل لواحق الملفات المسموح بها',

	// F
	'form_pet_message_commentaire' => 'أي رسالة أو تعليق؟',
	'forum' => 'المنتدى',
	'forum_acces_refuse' => 'لم تعد تتمتع بحق الدخول إلى هذه المنتديات.',
	'forum_attention_dix_caracteres' => '<b>تحذير!</b> يجب أن تحتوي رسالتك على عشرة حروف على الأقل.',
	'forum_attention_message_non_poste' => 'تحذير، لم تقم ببعث رسالتك!',
	'forum_attention_nb_caracteres_mini' => '<b>تحذير!</b> يجب أن تحتوي رسالتك على @min@ حرف على الأقل.',
	'forum_attention_trois_caracteres' => '<b>تحذير!</b> يجب أن يحتوي موضوعك على ثلاثة حروف على الأقل.',
	'forum_attention_trop_caracteres' => '<b>تحذير!</b> رسالتك طويلة جداً (@compte@ حرف): لكي يتم تسجيلها، لا يجب ان تتعدى @max@ حرف.',
	'forum_avez_selectionne' => 'لقد حددت:',
	'forum_cliquer_retour' => 'انقر <a href=\'@retour_forum@\'>هنا</a> للمتابعة.',
	'forum_envoyer' => 'إرسال',
	'forum_forum' => 'منتدى',
	'forum_info_modere' => 'هذا المنتدى مراقب استباقياً: لن تظهر مشاركتك إلا بعد التصديق عليها من قبل أحد المدراء.',
	'forum_lien_hyper' => 'رابط هايبرتكست',
	'forum_message' => 'مشاركتك',
	'forum_message_definitif' => 'مشاركة نهائية: إرسال إلى الموقع',
	'forum_message_trop_long' => 'مشاركتك طويلة جداً. لا يجب أن تتعدى الحد الأقصى وهو ٢٠٠٠٠ حرف.',
	'forum_ne_repondez_pas' => 'لا ترد على هذه الرسالة بل في المنتدى على العنوان التالي:',
	'forum_page_url' => '(إذا كانت مشاركتك تشير إلى مقال منشور على النسيج أو صفحة توفر المزيد من المعلومات، الرجاء إدخال اسم هذه الصفحة وعنوانها أدناه).',
	'forum_permalink' => 'رابط دائم الى التعليق',
	'forum_poste_par' => 'مشاركة مرسلة@parauteur@ تعقيباً على المقال «@titre@».',
	'forum_poste_par_court' => 'مشاركة مرسلة@parauteur@.',
	'forum_poste_par_generique' => 'مشاركة مرسلة@parauteur@ (@objet@ « @titre@ »).',
	'forum_qui_etes_vous' => 'من أنت؟',
	'forum_saisie_texte_info' => 'تدعم هذه الاستمارة اختصارات SPIP <code>[-&gt;url] {{أسود}} {مائل} &lt;quote&gt; &lt;code&gt;</code> وعلامات HTML <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. لإنشاء فقرات أترك اسطر فارغة.',
	'forum_texte' => 'نص المشاركة',
	'forum_titre' => 'الموضوع',
	'forum_url' => 'موقعك',
	'forum_valider' => 'التصديق على هذا الخيار',
	'forum_voir_avant' => 'معاينة',
	'forum_votre_email' => 'عنوانك الإلكتروني',
	'forum_votre_nom' => 'اسمك',
	'forum_vous_enregistrer' => 'قبل الاشتراك في
  هذا المنتدى، يجب أن تسجل نفسك. الرجاء
  إدخال أدناه المعرّف الشخصي الذي
  حصلت عليه. إذا لم يسبق لك التسجيل يجب',
	'forum_vous_inscrire' => 'ان تسجل نفسك.',

	// I
	'icone_bruler_message' => 'تحديد كرسالة خنزرة',
	'icone_bruler_messages' => 'تحدبد كرسالة خنزرة',
	'icone_legitimer_message' => 'تحديد كمشاركة صالحة',
	'icone_poster_message' => 'إرسال مشاركة',
	'icone_suivi_forum' => 'متابعة المنتدى العام: @nb_forums@ مشاركة',
	'icone_suivi_forums' => 'متابعة/إدارة المنتديات',
	'icone_supprimer_message' => 'حذف هذه المشاركة',
	'icone_supprimer_messages' => 'خذف هذه المشاركات',
	'icone_valider_message' => 'التصديق على هذه المشاركة',
	'icone_valider_messages' => 'التصديق على هذه المشاركات',
	'icone_valider_repondre_message' => 'التصديق على هذه المشاركة والرد عليها',
	'info_1_message_forum' => 'مشاركة منتدى واحدة',
	'info_activer_forum_public' => 'لتفعيل المنتديات العامة، الرجاء إختيار وضعية
المراقبة الافتراضية:',
	'info_appliquer_choix_moderation' => 'تطبيق خيار المراقبة هذا:',
	'info_config_forums_prive' => 'في المجال الخاص للموقع، يمكنك تفعيل عدة انواع من المنتديات:',
	'info_config_forums_prive_admin' => 'منتدى مخصص لمدراء الموقع:',
	'info_config_forums_prive_global' => 'منتدى شامل، مفتوح لجميع المحررين:',
	'info_config_forums_prive_objets' => 'منتدى تحت كل مقال او خبر او موقع مبوّب الخ:',
	'info_desactiver_forum_public' => 'ايقاف استخدام المنتديات
العامة. تتم إتاحة المنتديات العامة حسب كل حالة
للمقالات؛ وستكون محظورة في الأقسام والأخبار الخ.',
	'info_envoi_forum' => 'إرسال المنتديات الى مؤلفي المقالات',
	'info_fonctionnement_forum' => 'تشغيل المنتدى:',
	'info_forcer_previsualisation_court' => 'فرض المعاينة المسبقة',
	'info_forcer_previsualisation_long' => 'فرض المعاينة المسبقة قبل إرسال المشاركة',
	'info_forums_liees_mot' => 'مشاركات المنتدى المرتبطة بهذا المفتاح',
	'info_gauche_suivi_forum_2' => 'صفحة <i>متابعة المنتديات</i> هي أداة إدارية في موقعك (وليست للنقاش او التحرير). وتعرض هذه الصفحة كل مشاركات منتديات الموقع، العمومية منها كما الخاصة وتتيح لك التحكم بهذه المشاركات.',
	'info_liens_syndiques_3' => 'منتدى',
	'info_liens_syndiques_4' => 'هي',
	'info_liens_syndiques_5' => 'منتدى',
	'info_liens_syndiques_6' => 'هو',
	'info_liens_syndiques_7' => 'بانتظار التصديق',
	'info_liens_texte' => 'الرابط او الروابط الموجودة في نص المشاركة',
	'info_liens_titre' => 'الرتبط او الروابط الموجودة في عنوان المشاركة',
	'info_mode_fonctionnement_defaut_forum_public' => 'الوضعية الافتراضية لتشغيل المنتديات العامة',
	'info_nb_messages_forum' => '@nb@ مشاركة منتدى',
	'info_option_email' => 'عندما يبعث احد زوار الموقع بمشاركة الى المنتدى المرتبط بأحد المقالات، يمكن إعلام مؤلفي المقال بهذه المشاركة بواسطة البريد الالكتروني. عليك بتحديد استخدام هذا الخيار ام لا لكل نوع من المنتديات.',
	'info_pas_de_forum' => 'بدون منتديات',
	'info_question_visiteur_ajout_document_forum' => 'اذا اردت السماح للزوار بإرفاق مستندات (صور، اصوات،...) بمشاركاتهم في المنتدى، حدد هنا لائحة لواحق المستندات المسموح بها في المنتديات (مثلاً: gif او jpg او png او mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'اذا اردت السماح بكل انواع المستندات التي يعتبرها SPIP آمنة، ضع نجمة (*).اما اذا اردت عدم السماح بأي نوع، فلا تدخل أي شيء.',
	'info_selectionner_message' => 'تحديد الرسائل:',
	'interface_formulaire' => 'واجهة الاستمارة',
	'interface_onglets' => 'واجهة مقسّمة',
	'item_activer_forum_administrateur' => 'تفعيل منتدى المدراء',
	'item_config_forums_prive_global' => 'تفعيل منتدى المحررين',
	'item_config_forums_prive_objets' => 'تفعيل هذه المنتديات',
	'item_desactiver_forum_administrateur' => 'ايقاف منتدى المدراء',
	'item_non_config_forums_prive_global' => 'تعطيل منتدى المحررين',
	'item_non_config_forums_prive_objets' => 'تعطيل هذه المنتديات',

	// L
	'label_selectionner' => 'تحديد:',
	'lien_reponse_article' => 'الرد على المقال',
	'lien_reponse_breve_2' => 'الرد على الخبر',
	'lien_reponse_message' => 'الرد على المشاركة',
	'lien_reponse_rubrique' => 'الرد على القسم',
	'lien_reponse_site_reference' => 'الرد على الموقع المبوب',
	'lien_vider_selection' => 'تفريغ التحديد',

	// M
	'messages_aucun' => 'غير موجود',
	'messages_meme_auteur' => 'كل مشاركات هذا المؤلف',
	'messages_meme_email' => 'كل مشاركات هذا العنوان البريدي',
	'messages_meme_ip' => 'كل مشاركات عنوان IP',
	'messages_off' => 'حذفت',
	'messages_perso' => 'شخصية',
	'messages_privadm' => 'المدراء',
	'messages_prive' => 'خاصة',
	'messages_privoff' => 'حذفت',
	'messages_privrac' => 'عامة',
	'messages_prop' => 'مقترحة',
	'messages_publie' => 'منشورة',
	'messages_spam' => 'خنزرة',
	'messages_tous' => 'الكل',

	// O
	'onglet_messages_internes' => 'الرسائل الداخلية',
	'onglet_messages_publics' => 'المشاركات العامة',
	'onglet_messages_vide' => 'رسائل بدون نص',

	// R
	'repondre_message' => 'الرد على هذه المشاركة',

	// S
	'statut_off' => 'محذوفة',
	'statut_original' => 'اصلي',
	'statut_prop' => 'مقترحة',
	'statut_publie' => 'منشورة',
	'statut_spam' => 'خنزرة',

	// T
	'text_article_propose_publication_forum' => 'لا تتردد في إبداء رأيك عليه من خلال المنتدى المرتبط به (في أسفل الصفحة).',
	'texte_en_cours_validation' => 'المحتويات أدناه معروضة للنشر.',
	'texte_en_cours_validation_forum' => 'لا تتردد في إبداء رأيك من خلال المنتديات المرتبطة بها.',
	'texte_messages_publics' => 'مشاركات عمومية في:',
	'titre_cadre_forum_administrateur' => 'منتدى المدراء الخاص',
	'titre_cadre_forum_interne' => 'المنتدى الداخلي',
	'titre_config_forums_prive' => 'منتديات المجال الخاص',
	'titre_forum' => 'المنتدى',
	'titre_forum_suivi' => 'متابعة المنتديات',
	'titre_page_forum_suivi' => 'متابعة المنتديات',
	'titre_selection_action' => 'التحديد',
	'tout_voir' => 'عرض كل المشاركات',

	// V
	'voir_messages_objet' => 'عرض المشاركات'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/forum/lang/forum_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/forum?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_message_forum' => 'لا يوجد مشاركات منتدى',

	// B
	'bouton_radio_articles_futurs' => 'على المقالات المستقبلية فقط (لا تأثير على قاعدة البيانات).',
	'bouton_radio_articles_tous' => 'على كل المقالات دون استثناء.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'على كل المقالات باستثناء المقالات ذات المنتديات المتوقفة.',
	'bouton_radio_enregistrement_obligatoire' => 'تسجيل إجباري (
يجب على المستخدمين التسجيل بإدخال عنوانهم البريدي قبل
التمكن من إرسال المشاركات).',
	'bouton_radio_moderation_priori' => 'مراقبة استباقية (
لا تظهر المشاركات إلا بعد تصديقها من قبل
المدراء).',
	'bouton_radio_modere_abonnement' => 'اشتراك إجباري',
	'bouton_radio_modere_posteriori' => 'مراقبة بعدية',
	'bouton_radio_modere_priori' => 'مراقبة استباقية',
	'bouton_radio_publication_immediate' => 'نشر فوري للمشاركات
(ستظهر المشاركات حال إرسالها، ويمكن للمدراء
حذفها وقتذاك).',

	// D
	'documents_interdits_forum' => 'المستندات ممنوعة في المنتدى',

	// E
	'erreur_enregistrement_message' => 'لم يتم تسجيل مشاركتك بسبب مشكلة تقنية',
	'extensions_autorisees' => 'اللواحق المسموح بها:',
	'extensions_autorisees_toutes' => 'الكل',

	// F
	'form_pet_message_commentaire' => 'أي رسالة أو تعليق؟',
	'forum' => 'المنتدى',
	'forum_acces_refuse' => 'لم تعد تتمتع بحق الدخول إلى هذه المنتديات.',
	'forum_attention_dix_caracteres' => '<b>تحذير!</b> يجب أن تحتوي رسالتك على عشرة حروف على الأقل.',
	'forum_attention_message_non_poste' => 'تحذير، لم تقم ببعث رسالتك!',
	'forum_attention_nb_caracteres_mini' => '<b>تحذير!</b> يجب أن تحتوي رسالتك على @min@ حرف على الأقل.',
	'forum_attention_trois_caracteres' => '<b>تحذير!</b> يجب أن يحتوي موضوعك على ثلاثة حروف على الأقل.',
	'forum_attention_trop_caracteres' => '<b>تحذير!</b> رسالتك طويلة جداً (@compte@ حرف): لكي يتم تسجيلها، لا يجب ان تتعدى @max@ حرف.',
	'forum_avez_selectionne' => 'لقد حددت:',
	'forum_cliquer_retour' => 'انقر <a href=\'@retour_forum@\'>هنا</a> للمتابعة.',
	'forum_envoyer' => 'إرسال',
	'forum_forum' => 'منتدى',
	'forum_info_modere' => 'هذا المنتدى مراقب استباقياً: لن تظهر مشاركتك إلا بعد التصديق عليها من قبل أحد المدراء.',
	'forum_lien_hyper' => 'رابط هايبرتكست',
	'forum_message' => 'مشاركتك',
	'forum_message_definitif' => 'مشاركة نهائية: إرسال إلى الموقع',
	'forum_message_trop_long' => 'مشاركتك طويلة جداً. لا يجب أن تتعدى الحد الأقصى وهو ٢٠٠٠٠ حرف.',
	'forum_ne_repondez_pas' => 'لا ترد على هذه الرسالة بل في المنتدى على العنوان التالي:',
	'forum_page_url' => '(إذا كانت مشاركتك تشير إلى مقال منشور على النسيج أو صفحة توفر المزيد من المعلومات، الرجاء إدخال اسم هذه الصفحة وعنوانها أدناه).',
	'forum_permalink' => 'رابط دائم الى التعليق',
	'forum_poste_par' => 'مشاركة مرسلة@parauteur@ تعقيباً على المقال «@titre@».',
	'forum_poste_par_court' => 'مشاركة مرسلة@parauteur@.',
	'forum_poste_par_generique' => 'مشاركة مرسلة@parauteur@ (@objet@ « @titre@ »).',
	'forum_qui_etes_vous' => 'من أنت؟',
	'forum_saisie_texte_info' => 'تدعم هذه الاستمارة اختصارات SPIP <code>[-&gt;عنوان] {{أسود}} {مائل} &lt;اقتباس&gt; &lt;برمجة&gt;</code> وعلامات HTML <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. لإنشاء فقرات أترك اسطر فارغة.',
	'forum_texte' => 'نص المشاركة',
	'forum_titre' => 'الموضوع',
	'forum_url' => 'موقعك',
	'forum_valider' => 'التصديق على هذا الخيار',
	'forum_voir_avant' => 'معاينة',
	'forum_votre_email' => 'عنوانك الإلكتروني',
	'forum_votre_nom' => 'اسمك',
	'forum_vous_enregistrer' => 'قبل الاشتراك في
  هذا المنتدى، يجب أن تسجل نفسك. الرجاء
  إدخال أدناه المعرّف الشخصي الذي
  حصلت عليه. إذا لم يسبق لك التسجيل يجب',
	'forum_vous_inscrire' => 'ان تسجل نفسك.',

	// I
	'icone_bruler_message' => 'تحديد كرسالة خنزرة',
	'icone_bruler_messages' => 'تحدبد كرسالة خنزرة',
	'icone_legitimer_message' => 'تحديد كمشاركة صالحة',
	'icone_poster_message' => 'إرسال مشاركة',
	'icone_suivi_forum' => 'متابعة المنتدى العام: @nb_forums@ مشاركة',
	'icone_suivi_forums' => 'متابعة/إدارة المنتديات',
	'icone_supprimer_message' => 'حذف هذه المشاركة',
	'icone_supprimer_messages' => 'خذف هذه المشاركات',
	'icone_valider_message' => 'التصديق على هذه المشاركة',
	'icone_valider_messages' => 'التصديق على هذه المشاركات',
	'icone_valider_repondre_message' => 'التصديق على هذه المشاركة والرد عليها',
	'info_1_message_forum' => 'مشاركة منتدى واحدة',
	'info_activer_forum_public' => 'لتفعيل المنتديات العامة، الرجاء إختيار وضعية
المراقبة الافتراضية:',
	'info_appliquer_choix_moderation' => 'تطبيق خيار المراقبة هذا:',
	'info_config_forums_prive' => 'في المجال الخاص للموقع، يمكنك تفعيل عدة انواع من المنتديات:',
	'info_config_forums_prive_admin' => 'منتدى مخصص لمدراء الموقع:',
	'info_config_forums_prive_global' => 'منتدى شامل، مفتوح لجميع المحررين:',
	'info_config_forums_prive_objets' => 'منتدى تحت كل مقال او خبر او موقع مبوّب الخ:',
	'info_desactiver_forum_public' => 'ايقاف استخدام المنتديات
العامة. تتم إتاحة المنتديات العامة حسب كل حالة
للمقالات؛ وستكون محظورة في الأقسام والأخبار الخ.',
	'info_envoi_forum' => 'إرسال المنتديات الى مؤلفي المقالات',
	'info_fonctionnement_forum' => 'تشغيل المنتدى:',
	'info_forcer_previsualisation_court' => 'فرض المعاينة المسبقة',
	'info_forcer_previsualisation_long' => 'فرض المعاينة المسبقة قبل إرسال المشاركة',
	'info_forums_liees_mot' => 'مشاركات المنتدى المرتبطة بهذا المفتاح',
	'info_gauche_suivi_forum_2' => 'صفحة <i>متابعة المنتديات</i> هي أداة إدارية في موقعك (وليست للنقاش او التحرير). وتعرض هذه الصفحة كل مشاركات منتديات الموقع، العمومية منها كما الخاصة وتتيح لك التحكم بهذه المشاركات.',
	'info_liens_syndiques_3' => 'منتدى',
	'info_liens_syndiques_4' => 'هي',
	'info_liens_syndiques_5' => 'منتدى',
	'info_liens_syndiques_6' => 'هو',
	'info_liens_syndiques_7' => 'بانتظار التصديق',
	'info_liens_texte' => 'الرابط او الروابط الموجودة في نص المشاركة',
	'info_liens_titre' => 'الرتبط او الروابط الموجودة في عنوان المشاركة',
	'info_mode_fonctionnement_defaut_forum_public' => 'الوضعية الافتراضية لتشغيل المنتديات العامة',
	'info_nb_messages_forum' => '@nb@ مشاركة منتدى',
	'info_option_email' => 'عندما يبعث احد زوار الموقع بمشاركة الى المنتدى المرتبط بأحد المقالات، يمكن إعلام مؤلفي المقال بهذه المشاركة بواسطة البريد الالكتروني. عليك بتحديد استخدام هذا الخيار ام لا لكل نوع من المنتديات.',
	'info_pas_de_forum' => 'بدون منتديات',
	'info_question_visiteur_ajout_document_forum' => 'اذا اردت السماح للزوار بإرفاق مستندات (صور، اصوات،...) بمشاركاتهم في المنتدى، حدد هنا لائحة لواحق المستندات المسموح بها في المنتديات (مثلاً: gif او jpg او png او mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'اذا اردت السماح بكل انواع المستندات التي يعتبرها SPIP آمنة، ضع نجمة (*).اما اذا اردت عدم السماح بأي نوع، فلا تدخل أي شيء.',
	'info_selectionner_message' => 'تحديد الرسائل:',
	'interface_formulaire' => 'واجهة الاستمارة',
	'interface_onglets' => 'واجهة مقسّمة',
	'item_activer_forum_administrateur' => 'تفعيل منتدى المدراء',
	'item_config_forums_prive_global' => 'تفعيل منتدى المحررين',
	'item_config_forums_prive_objets' => 'تفعيل هذه المنتديات',
	'item_desactiver_forum_administrateur' => 'ايقاف منتدى المدراء',
	'item_non_config_forums_prive_global' => 'تعطيل منتدى المحررين',
	'item_non_config_forums_prive_objets' => 'تعطيل هذه المنتديات',

	// L
	'label_selectionner' => 'تحديد:',
	'lien_reponse_article' => 'الرد على المقال',
	'lien_reponse_breve_2' => 'الرد على الخبر',
	'lien_reponse_message' => 'الرد على المشاركة',
	'lien_reponse_rubrique' => 'الرد على القسم',
	'lien_reponse_site_reference' => 'الرد على الموقع المبوب',
	'lien_vider_selection' => 'تفريغ التحديد',

	// M
	'messages_aucun' => 'غير موجود',
	'messages_meme_auteur' => 'كل مشاركات هذا المؤلف',
	'messages_meme_email' => 'كل مشاركات هذا العنوان البريدي',
	'messages_meme_ip' => 'كل مشاركات عنوان IP',
	'messages_off' => 'حذفت',
	'messages_perso' => 'شخصية',
	'messages_privadm' => 'المدراء',
	'messages_prive' => 'خاصة',
	'messages_privoff' => 'حذفت',
	'messages_privrac' => 'عامة',
	'messages_prop' => 'مقترحة',
	'messages_publie' => 'منشورة',
	'messages_spam' => 'خنزرة',
	'messages_tous' => 'الكل',

	// O
	'onglet_messages_internes' => 'الرسائل الداخلية',
	'onglet_messages_publics' => 'المشاركات العامة',
	'onglet_messages_vide' => 'رسائل بدون نص',

	// R
	'repondre_message' => 'الرد على هذه المشاركة',

	// S
	'statut_off' => 'محذوفة',
	'statut_original' => 'اصلي',
	'statut_prop' => 'مقترحة',
	'statut_publie' => 'منشورة',
	'statut_spam' => 'خنزرة',

	// T
	'text_article_propose_publication_forum' => 'لا تتردد في إبداء رأيك عليه من خلال المنتدى المرتبط به (في أسفل الصفحة).',
	'texte_en_cours_validation' => 'المحتويات أدناه معروضة للنشر.',
	'texte_en_cours_validation_forum' => 'لا تتردد في إبداء رأيك من خلال المنتديات المرتبطة بها.',
	'texte_messages_publics' => 'مشاركات عمومية في:',
	'titre_cadre_forum_administrateur' => 'منتدى المدراء الخاص',
	'titre_cadre_forum_interne' => 'المنتدى الداخلي',
	'titre_config_forums_prive' => 'منتديات المجال الخاص',
	'titre_forum' => 'المنتدى',
	'titre_forum_suivi' => 'متابعة المنتديات',
	'titre_page_forum_suivi' => 'متابعة المنتديات',
	'titre_selection_action' => 'التحديد',
	'tout_voir' => 'عرض كل المشاركات',

	// V
	'voir_messages_objet' => 'عرض المشاركات'
);

?>
